""" 
short summery of module

A more detailes explanation.
"""


def convert(Path):
    """
    Convert the given PDF to text.(a short summery of object)

    more details about function is represented here.
    Parameters:
    (What Path is, its type, what we use it for)
    Path(str): The path to a PDF file.
    ...

    Returns:
    str: The content of the PDF file as text.
    """
    print("convert function: Pdf2Text")
